summaryrefslogtreecommitdiff
path: root/drivers/oled/ssd1306_sh1106.c
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/oled/ssd1306_sh1106.c')
-rw-r--r--drivers/oled/ssd1306_sh1106.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/drivers/oled/ssd1306_sh1106.c b/drivers/oled/ssd1306_sh1106.c
index 9fc8c2d2ad..342920572e 100644
--- a/drivers/oled/ssd1306_sh1106.c
+++ b/drivers/oled/ssd1306_sh1106.c
@@ -300,8 +300,9 @@ void oled_render(void) {
// Turn on display if it is off
oled_on();
- uint8_t update_start = 0;
- while (oled_dirty) { // render all dirty blocks
+ uint8_t update_start = 0;
+ uint8_t num_processed = 0;
+ while (oled_dirty && num_processed++ < OLED_UPDATE_PROCESS_LIMIT) { // render all dirty blocks (up to the configured limit)
// Find next dirty block
while (!(oled_dirty & ((OLED_BLOCK_TYPE)1 << update_start))) {
++update_start;